==> saods9_6.2%2Bdfsg.orig.tar.gz: saods9/saotk/frame/boxannulus.h <==
// Copyright (C) 1999-2010
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __boxannulus_h__
#define __boxannulus_h__

#include "basebox.h"

class BoxAnnulus : public BaseBox {
public:
  BoxAnnulus(const BoxAnnulus&);
  BoxAnnulus(FrameBase* p, const Vector& ctr,
	     const Vector& s, 
	     double ang,
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt, 
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);
  BoxAnnulus(FrameBase* p, const Vector& ctr,
	     const Vector& inner, const Vector& outer, int num,
	     double ang,
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt, 
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);
  BoxAnnulus(FrameBase* p, const Vector& ctr, 
	     int an, Vector* s,
	     double ang, 
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt,
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);

  Marker* dup() {return new BoxAnnulus(*this);}
  void editBegin(int);
  void edit(const Vector&, int);
  void editEnd();

  int addAnnuli(const Vector&);

  void list(ostream&, CoordSystem, SkyFrame, SkyFormat, int, int);
  void listXML(ostream&, CoordSystem, SkyFrame, SkyFormat);
  void listPros(ostream&, CoordSystem, SkyFrame, SkyFormat, int);
  void listSAOimage(ostream&, int);
};

#endif

==> saods9_7.0.1%2Bdfsg.orig.tar.gz: saods9/saotk/frame/boxannulus.h <==
// Copyright (C) 1999-2012
// Smithsonian Astrophysical Observatory, Cambridge, MA, USA
// For conditions of distribution and use, see copyright notice in "copyright"

#ifndef __boxannulus_h__
#define __boxannulus_h__

#include "basebox.h"

class BoxAnnulus : public BaseBox {
public:
  BoxAnnulus(const BoxAnnulus&);
  BoxAnnulus(Base* p, const Vector& ctr,
	     const Vector& s, 
	     double ang,
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt, 
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);
  BoxAnnulus(Base* p, const Vector& ctr,
	     const Vector& inner, const Vector& outer, int num,
	     double ang,
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt, 
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);
  BoxAnnulus(Base* p, const Vector& ctr, 
	     int an, Vector* s,
	     double ang, 
	     const char* clr, int* dsh,
	     int wth, const char* fnt, const char* txt,
	     unsigned short prop, const char* cmt,
	     const List<Tag>& tg, const List<CallBack>& cb);

  Marker* dup() {return new BoxAnnulus(*this);}
  void editBegin(int);
  void edit(const Vector&, int);
  void editEnd();

  int addAnnuli(const Vector&);

  void list(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int, int);
  void listXML(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
  void listPros(ostream&, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat, int);
  void listSAOimage(ostream&, int);
};

#endif
